==> ruby-mysql2_0.5.2.orig.tar.gz: mysql2-0.5.2/ext/mysql2/mysql_enc_to_ruby.h <==
static const char *mysql2_mysql_enc_to_rb[] = {
  "Big5",
  "ISO-8859-2",
  NULL,
  "CP850",
  "ISO-8859-1",
  NULL,
  "KOI8-R",
  "ISO-8859-1",
  "ISO-8859-2",
  NULL,
  "US-ASCII",
  "eucJP-ms",
  "Shift_JIS",
  "Windows-1251",
  "ISO-8859-1",
  "ISO-8859-8",
  NULL,
  "TIS-620",
  "EUC-KR",
  "ISO-8859-13",
  "ISO-8859-2",
  "KOI8-R",
  "Windows-1251",
  "GB2312",
  "ISO-8859-7",
  "Windows-1250",
  "ISO-8859-2",
  "GBK",
  "Windows-1257",
  "ISO-8859-9",
  "ISO-8859-1",
  NULL,
  "UTF-8",
  "Windows-1250",
  "UTF-16BE",
  "IBM866",
  NULL,
  "macCentEuro",
  "macRoman",
  "CP852",
  "ISO-8859-13",
  "ISO-8859-13",
  "macCentEuro",
  "Windows-1250",
  "UTF-8",
  "UTF-8",
  "ISO-8859-1",
  "ISO-8859-1",
  "ISO-8859-1",
  "Windows-1251",
  "Windows-1251",
  "Windows-1251",
  "macRoman",
  "UTF-16",
  "UTF-16",
  "",
  "Windows-1256",
  "Windows-1257",
  "Windows-1257",
  "UTF-32",
  "UTF-32",
  "",
  "ASCII-8BIT",
  NULL,
  "US-ASCII",
  "Windows-1250",
  "Windows-1256",
  "IBM866",
  NULL,
  "ISO-8859-7",
  "ISO-8859-8",
  NULL,
  NULL,
  "KOI8-R",
  "KOI8-R",
  NULL,
  "ISO-8859-2",
  "ISO-8859-9",
  "ISO-8859-13",
  "CP850",
  "CP852",
  NULL,
  "UTF-8",
  "Big5",
  "EUC-KR",
  "GB2312",
  "GBK",
  "Shift_JIS",
  "TIS-620",
  "UTF-16BE",
  "eucJP-ms",
  NULL,
  NULL,
  "ISO-8859-1",
  "Windows-31J",
  "Windows-31J",
  "eucJP-ms",
  "eucJP-ms",
  "Windows-1250",
  NULL,
  "UTF-16",
  "UTF-16",
  "UTF-16",
  "UTF-16",
  "UTF-16",
  "UTF-16",
  "UTF-16",
  "UTF-16",
  "UTF-16",
  "UTF-16",
  "UTF-16",
  "UTF-16",
  "UTF-16",
  "UTF-16",
  "UTF-16",
  "UTF-16",
  "UTF-16",
  "UTF-16",
  "UTF-16",
  "UTF-16",
  "UTF-16",
  "UTF-16",
  "UTF-16",
  "UTF-16",
  NULL,
  NULL,
  NULL,
  "UTF-16BE",
  "UTF-16BE",
  "UTF-16BE",
  "UTF-16BE",
  "UTF-16BE",
  "UTF-16BE",
  "UTF-16BE",
  "UTF-16BE",
  "UTF-16BE",
  "UTF-16BE",
  "UTF-16BE",
  "UTF-16BE",
  "UTF-16BE",
  "UTF-16BE",
  "UTF-16BE",
  "UTF-16BE",
  "UTF-16BE",
  "UTF-16BE",
  "UTF-16BE",
  "UTF-16BE",
  "UTF-16BE",
  "UTF-16BE",
  "UTF-16BE",
  "UTF-16BE",
  NULL,
  NULL,
  NULL,
  NULL,
  NULL,
  NULL,
  NULL,
  "UTF-16BE",
  "UTF-32",
  "UTF-32",
  "UTF-32",
  "UTF-32",
  "UTF-32",
  "UTF-32",
  "UTF-32",
  "UTF-32",
  "UTF-32",
  "UTF-32",
  "UTF-32",
  "UTF-32",
  "UTF-32",
  "UTF-32",
  "UTF-32",
  "UTF-32",
  "UTF-32",
  "UTF-32",
  "UTF-32",
  "UTF-32",
  "UTF-32",
  "UTF-32",
  "UTF-32",
  "UTF-32",
  NULL,
  NULL,
  NULL,
  NULL,
  NULL,
  NULL,
  NULL,
  NULL,
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  NULL,
  NULL,
  NULL,
  NULL,
  NULL,
  NULL,
  NULL,
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  NULL,
  NULL,
  NULL,
  NULL,
  NULL,
  NULL,
  NULL,
  "UTF-8"
};

#define CHARSETNR_SIZE (sizeof(mysql2_mysql_enc_to_rb)/sizeof(mysql2_mysql_enc_to_rb[0]))

==> ruby-mysql2_0.5.3.orig.tar.gz: mysql2-0.5.3/ext/mysql2/mysql_enc_to_ruby.h <==
static const char *mysql2_mysql_enc_to_rb[] = {
  "Big5",
  "ISO-8859-2",
  NULL,
  "CP850",
  "ISO-8859-1",
  NULL,
  "KOI8-R",
  "ISO-8859-1",
  "ISO-8859-2",
  NULL,
  "US-ASCII",
  "eucJP-ms",
  "Shift_JIS",
  "Windows-1251",
  "ISO-8859-1",
  "ISO-8859-8",
  NULL,
  "TIS-620",
  "EUC-KR",
  "ISO-8859-13",
  "ISO-8859-2",
  "KOI8-R",
  "Windows-1251",
  "GB2312",
  "ISO-8859-7",
  "Windows-1250",
  "ISO-8859-2",
  "GBK",
  "Windows-1257",
  "ISO-8859-9",
  "ISO-8859-1",
  NULL,
  "UTF-8",
  "Windows-1250",
  "UTF-16BE",
  "IBM866",
  NULL,
  "macCentEuro",
  "macRoman",
  "CP852",
  "ISO-8859-13",
  "ISO-8859-13",
  "macCentEuro",
  "Windows-1250",
  "UTF-8",
  "UTF-8",
  "ISO-8859-1",
  "ISO-8859-1",
  "ISO-8859-1",
  "Windows-1251",
  "Windows-1251",
  "Windows-1251",
  "macRoman",
  "UTF-16",
  "UTF-16",
  "UTF-16LE",
  "Windows-1256",
  "Windows-1257",
  "Windows-1257",
  "UTF-32",
  "UTF-32",
  "UTF-16LE",
  "ASCII-8BIT",
  NULL,
  "US-ASCII",
  "Windows-1250",
  "Windows-1256",
  "IBM866",
  NULL,
  "ISO-8859-7",
  "ISO-8859-8",
  NULL,
  NULL,
  "KOI8-R",
  "KOI8-R",
  "UTF-8",
  "ISO-8859-2",
  "ISO-8859-9",
  "ISO-8859-13",
  "CP850",
  "CP852",
  NULL,
  "UTF-8",
  "Big5",
  "EUC-KR",
  "GB2312",
  "GBK",
  "Shift_JIS",
  "TIS-620",
  "UTF-16BE",
  "eucJP-ms",
  NULL,
  NULL,
  "ISO-8859-1",
  "Windows-31J",
  "Windows-31J",
  "eucJP-ms",
  "eucJP-ms",
  "Windows-1250",
  NULL,
  "UTF-16",
  "UTF-16",
  "UTF-16",
  "UTF-16",
  "UTF-16",
  "UTF-16",
  "UTF-16",
  "UTF-16",
  "UTF-16",
  "UTF-16",
  "UTF-16",
  "UTF-16",
  "UTF-16",
  "UTF-16",
  "UTF-16",
  "UTF-16",
  "UTF-16",
  "UTF-16",
  "UTF-16",
  "UTF-16",
  "UTF-16",
  "UTF-16",
  "UTF-16",
  "UTF-16",
  NULL,
  NULL,
  NULL,
  "UTF-16BE",
  "UTF-16BE",
  "UTF-16BE",
  "UTF-16BE",
  "UTF-16BE",
  "UTF-16BE",
  "UTF-16BE",
  "UTF-16BE",
  "UTF-16BE",
  "UTF-16BE",
  "UTF-16BE",
  "UTF-16BE",
  "UTF-16BE",
  "UTF-16BE",
  "UTF-16BE",
  "UTF-16BE",
  "UTF-16BE",
  "UTF-16BE",
  "UTF-16BE",
  "UTF-16BE",
  "UTF-16BE",
  "UTF-16BE",
  "UTF-16BE",
  "UTF-16BE",
  NULL,
  NULL,
  NULL,
  NULL,
  NULL,
  NULL,
  NULL,
  "UTF-16BE",
  "UTF-32",
  "UTF-32",
  "UTF-32",
  "UTF-32",
  "UTF-32",
  "UTF-32",
  "UTF-32",
  "UTF-32",
  "UTF-32",
  "UTF-32",
  "UTF-32",
  "UTF-32",
  "UTF-32",
  "UTF-32",
  "UTF-32",
  "UTF-32",
  "UTF-32",
  "UTF-32",
  "UTF-32",
  "UTF-32",
  "UTF-32",
  "UTF-32",
  "UTF-32",
  "UTF-32",
  NULL,
  NULL,
  NULL,
  NULL,
  NULL,
  NULL,
  NULL,
  NULL,
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  NULL,
  NULL,
  NULL,
  NULL,
  NULL,
  NULL,
  NULL,
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "GB18030",
  "GB18030",
  "GB18030",
  NULL,
  NULL,
  NULL,
  NULL,
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  NULL,
  "UTF-8",
  "UTF-8",
  "UTF-8",
  NULL,
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  NULL,
  "UTF-8",
  "UTF-8",
  "UTF-8",
  NULL,
  "UTF-8",
  NULL,
  NULL,
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8",
  "UTF-8"
};
